@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { KinesisStreamsToLambda } = require('@aws-solutions-constructs/aws-kinesisstreams-lambda');
 
 new KinesisStreamsToLambda(stack, 'KinesisToLambdaPattern', {
-    deployLambda: true,
     eventSourceProps: {
         startingPosition: lambda.StartingPosition.TRIM_HORIZON,
         batchSize: 1
@@ -62,9 +61,8 @@ new KinesisStreamsToLambda(scope: Construct, id: string, props: KinesisStreamsTo
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the `existingLambdaObj` property.|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function. This property is required if `deployLambda` is set to false.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided props to override the default props for the Lambda function. This property is only required if `deployLambda` is set to true.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
 |eventSourceProps?|[`lambda.EventSourceMappingOptions`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.EventSourceMappingOptions.html)|Optional user-provided props to override the default props for the Lambda event source mapping.|
 
@@ -117,20 +115,33 @@ import aws_cdk.aws_lambda
 import aws_cdk.core
 
 
-class KinesisStreamsToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambda"):
+class KinesisStreamsToLambda(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambda",
+):
     """
     summary:
     :summary:: The KinesisStreamsToLambda class.
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, event_source_props: typing.Any=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, kinesis_stream_props: typing.Any=None, lambda_function_props: typing.Any=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        event_source_props: typing.Any = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        kinesis_stream_props: typing.Any = None,
+        lambda_function_props: typing.Any = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param event_source_props: Optional user-provided props to override the default props for the Lambda event source mapping. Default: - Default props are used.
-        :param existing_lambda_obj: An optional, existing Lambda function. This property is required if ``deployLambda`` is set to false. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
-        :param lambda_function_props: Optional user-provided props to override the default props for the Lambda function. This property is only required if ``deployLambda`` is set to true. Default: - Default props are used.
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
 
         access:
         :access:: public
@@ -139,7 +150,12 @@ class KinesisStreamsToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, js
         summary:
         :summary:: Constructs a new instance of the KinesisStreamsToLambda class.
         """
-        props = KinesisStreamsToLambdaProps(deploy_lambda=deploy_lambda, event_source_props=event_source_props, existing_lambda_obj=existing_lambda_obj, kinesis_stream_props=kinesis_stream_props, lambda_function_props=lambda_function_props)
+        props = KinesisStreamsToLambdaProps(
+            event_source_props=event_source_props,
+            existing_lambda_obj=existing_lambda_obj,
+            kinesis_stream_props=kinesis_stream_props,
+            lambda_function_props=lambda_function_props,
+        )
 
         jsii.create(KinesisStreamsToLambda, self, [scope, id, props])
 
@@ -159,35 +175,41 @@ class KinesisStreamsToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, js
         return jsii.get(self, "lambdaFunction")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambdaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'event_source_props': 'eventSourceProps', 'existing_lambda_obj': 'existingLambdaObj', 'kinesis_stream_props': 'kinesisStreamProps', 'lambda_function_props': 'lambdaFunctionProps'})
-class KinesisStreamsToLambdaProps():
-    def __init__(self, *, deploy_lambda: bool, event_source_props: typing.Any=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, kinesis_stream_props: typing.Any=None, lambda_function_props: typing.Any=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "event_source_props": "eventSourceProps",
+        "existing_lambda_obj": "existingLambdaObj",
+        "kinesis_stream_props": "kinesisStreamProps",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class KinesisStreamsToLambdaProps:
+    def __init__(
+        self,
+        *,
+        event_source_props: typing.Any = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        kinesis_stream_props: typing.Any = None,
+        lambda_function_props: typing.Any = None,
+    ) -> None:
         """The properties for the KinesisStreamsToLambda class.
 
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param event_source_props: Optional user-provided props to override the default props for the Lambda event source mapping. Default: - Default props are used.
-        :param existing_lambda_obj: An optional, existing Lambda function. This property is required if ``deployLambda`` is set to false. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
-        :param lambda_function_props: Optional user-provided props to override the default props for the Lambda function. This property is only required if ``deployLambda`` is set to true. Default: - Default props are used.
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         """
-        self._values = {
-            'deploy_lambda': deploy_lambda,
-        }
-        if event_source_props is not None: self._values["event_source_props"] = event_source_props
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if kinesis_stream_props is not None: self._values["kinesis_stream_props"] = kinesis_stream_props
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
-
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new Lambda function or use an existing Lambda function.
-
-        If set to false, you must provide an existing function for the ``existingLambdaObj`` property.
-
-        default
-        :default: - true
-        """
-        return self._values.get('deploy_lambda')
+        self._values = {}
+        if event_source_props is not None:
+            self._values["event_source_props"] = event_source_props
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if kinesis_stream_props is not None:
+            self._values["kinesis_stream_props"] = kinesis_stream_props
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def event_source_props(self) -> typing.Any:
@@ -196,18 +218,16 @@ class KinesisStreamsToLambdaProps():
         default
         :default: - Default props are used.
         """
-        return self._values.get('event_source_props')
+        return self._values.get("event_source_props")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """An optional, existing Lambda function.
-
-        This property is required if ``deployLambda`` is set to false.
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Any:
@@ -216,18 +236,16 @@ class KinesisStreamsToLambdaProps():
         default
         :default: - Default props are used.
         """
-        return self._values.get('kinesis_stream_props')
+        return self._values.get("kinesis_stream_props")
 
     @builtins.property
     def lambda_function_props(self) -> typing.Any:
-        """Optional user-provided props to override the default props for the Lambda function.
-
-        This property is only required if ``deployLambda`` is set to true.
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used.
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -236,7 +254,9 @@ class KinesisStreamsToLambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'KinesisStreamsToLambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "KinesisStreamsToLambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
